## SCENARIO 2: Zero output groups, 1 of other entities where possible; active scenario; valid

### INPUTS

#### GROUP 1: Unit Test

# | Title | Delimiter
--- | --- | ---
1 | Inner title 2 | :

####

#### GROUP 2: Input Fields

# | Group | Field
--- | --- | ---
1 | Input Group 1 | Input Field 1

####

#### GROUP 3: Output Fields: Empty

#### GROUP 4: Scenario

# | Scenario | Active Y/N
--- | --- | ---
1 | Inner scenario 1 | Y

####

#### GROUP 5: Input Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | Inner scenario 1 | Input Group 1 | Input value 1

####

#### GROUP 6: Expected Values: Empty

#### GROUP 7: Actual Values: Empty

### OUTPUTS

#### GROUP 1: Unit Test

# | Title | Delimiter
--- | --- | ---
1 | Inner title 2 | :

#### 0 failed of 1: SUCCESS

#### GROUP 2: Input Fields

# | Group | Field
--- | --- | ---
1 | Input Group 1 | Input Field 1

#### 0 failed of 1: SUCCESS

#### GROUP 3: Output Fields: Empty as expected: SUCCESS

#### GROUP 4: Input Values

# | Scenario | Group | Row CSV
--- | --- | --- | ---
1 | Inner scenario 1 | Input Group 1 | Input value 1

#### 0 failed of 1: SUCCESS

#### GROUP 5: Expected Values: Empty as expected: SUCCESS

#### GROUP 6: Actual Values: Empty as expected: SUCCESS

## 0 failed of 6: SUCCESS